//includes
#include  "msp430g2302.h"
#include  "I2C.h"

//Globalevariablen
unsigned int current_addr =0;
unsigned char eepromdata[32];


#ifndef EEPROM_ADDR
#define EEPROM_ADDR 0x50
#endif

/// Funktion zum Schreiben von Daten in das EEPROM
/*!
       Diese Funktion schreibt Daten ins EEPROM vom Typ 42LC512 von Microchip.
       Die aktuelle Speicherposition wird in einer globalen Variable erfasst.
       Doese Variable gibt aufschluss ber den verbleibenden Speicher im EEPROM.


      \param werte bergibt der Funktion einen Zeiger, der auf das erste Element des Datenfeldes zeigt.
      \param length Gibt an, wieviele Datenbytes in den Speicher geschrieben werden sollen.
 */
void WriteEEPROM(unsigned char* werte, unsigned char length){
  
  unsigned char txdata[3];
  unsigned char addr_h, addr_l;
  
  for(int i = 0; i<=length; i++){   
    addr_h = current_addr / 128;
    addr_l = current_addr;
  
   txdata[0] = addr_h;
   txdata[1] = addr_l;
   txdata[2] = *(werte+i);
   
   
   __disable_interrupt();   
   TI_USI_I2CWrite(EEPROM_ADDR, 3, 0, (unsigned char*)txdata);
   __bis_SR_register(LPM0_bits + GIE);
   
    while( TI_USI_I2CSelect(EEPROM_ADDR) ){} //ACK Polling bis Schreibvorgang beendet wurde
 
    current_addr++;
   
  }//ende for  
  
}
  
  


/// Funktion zum Lesen von Daten in das EEPROM
/*!
       Diese Funktion liest Daten aus einem EEPROM vom Typ 42LC512 von Microchip.       


      \param adresse bergibt der Funktion eine Adresse, von der angefangen wird Daten aus dem EEPROM zu lesen.
      \param length Gibt an, wieviele Datenbytes gelesen werden sollen.
 */
void ReadEEPROM(unsigned int adresse, unsigned char length){
  
  unsigned char rxdata[8];
  
  
    /*TI_USI_I2CRead(SlaveAddress,Length,Multi,RxData)*/
  __disable_interrupt();
  TI_USI_I2CRead(EEPROM_ADDR,7,0,rxdata);
  __bis_SR_register(LPM0_bits+GIE);
  
}




/// Funktion zum Lesen der aktuellen Schreib/Lese Adresse des EEPROMS
/*!
       Funktion zum Lesen der aktuellen Schreib/Lese Adresse des EEPROMS       



 */

unsigned char GetCurrentAddr(void){
   
  unsigned char rxdata = 0;
  
  
  __disable_interrupt();
  TI_USI_I2CRead(EEPROM_ADDR,7,0,(unsigned char*)rxdata);
  __bis_SR_register(LPM0_bits+GIE);


 return rxdata;
  
}



/// Funktion zum Lesen des gesammten EEPROMS
/*!
       Funktion zum Lesen der aktuellen Schreib/Lese Adresse des EEPROMS
       Dafr wird der Adresszeiger des EEPROMs zunchst auf 0000h gesetzt
       Anschlieend werden (bisher hartkodiert) 32 erste Datenbytes aus dem EEPROM gelesen



 */

void ReadEEPROMfromStart()
{
  
  
  unsigned char nullpointer[] = {0x00, 0x00};
  
     __disable_interrupt();   
   TI_USI_I2CWrite(EEPROM_ADDR, 2, 0, (unsigned char*)nullpointer);
   __bis_SR_register(LPM0_bits + GIE);
   

       __disable_interrupt();
  TI_USI_I2CRead(EEPROM_ADDR,64,0,(unsigned char*)eepromdata);
  __bis_SR_register(LPM0_bits+GIE);
     
  
  
}



