//includes
#include  "msp430g2302.h"
#include  "I2C.h"


#ifndef HYG_ADDR
#define HYG_ADDR 0x28
#endif

/// Funktion zum Lesen der Luftfeuchtigkeit
/*!
       Diese Funktion stellt eine (lesende) Verbindung zum Temperatur/Feuchtesensor
       HYT371 her.
       Aus den Rohdaten der I2C-bertragung wird die relative Feuchte berechnet.
       ber einen "Ping" wird der Messvorgang im Feuchtesensor gestartet.
       Nach einer Bearbeitungszeit knnen neue Werte fr Temperatur und Feuchte
       aus dem Sensor gelesen werden.

       
 */

unsigned char ReadHyg(unsigned char H){
  
  char raw = 0;
  
  unsigned char rxdata[4] = {
    
    0x00, //2 Status bits + 6 MSB Kapazittswert
    0x00, //8 LSB Kapazittswert
    
    0x00, //8 MSB Temperaturwert
    0x00, //6 LSB Temperaturwer
  };
  
  TI_USI_I2CSelect(HYG_ADDR);   //ber ein ACK-Request wird die Messung im Sensor ausgelst
  
  //__delay_cycles(10000);
  

  __disable_interrupt();
  TI_USI_I2CRead(HYG_ADDR,4,0,rxdata);
  __bis_SR_register(LPM0_bits+GIE);
  
  
  
  if(H >= 1){
 
    raw = 0x3FFF & (rxdata[0] << 8 | rxdata[1]); //2 Bytes mit Kapazittswerten werden zusammengefhrt und die 2 Statusbits entfernt  
    
    raw =  (char)((100.0/16384) *raw);           //Berechnung des der Luftfeuchte [%] und Rckgabe
    

   
    return raw;
  }
  else {
    
    
    rxdata[3] = (rxdata[3] &= 0x3F); //2 least significant Bits maskieren
    raw = rxdata[2] << 6 | rxdata[3];
    raw = (char) (165.0/16384*raw-40);
     

    
    return raw;  
  }
  
}