//includes
#include  "msp430g2302.h"
#include  "I2C.h"
#include  "String.h"




#ifndef LCD_ADDR
#define LCD_ADDR    0x3A
#endif

/// InitLCD
/*!
       Inittialisierung des LCD vom Typ EAT123 I2C
       mit folgenden Eigenschaften:
       -voltage generator aktiv weil durch bisher nicht identifizierten Fehler (trotz aktiviertem Inverter) keine Anzeige auf dem Display erscheint.
       -Display wird als 4x12 Zeichen Display initialisiert. Letzte Zeile ist nicht sichtbar

 */
void InitLCD()
{
  
  unsigned char lcd_init[] = {
    0x00,   //nachfolgende sind Controllbytes,
    0x3E,   //Interfacelenght, 4Line, Genertor,
    0x0E,   //Display ON, Cursur OFF, Blink OFF, 
    0x06,
    0x01    //Clear LCD und Reset Cursor
  }; 
   

  __disable_interrupt();
  TI_USI_I2CWrite(LCD_ADDR, sizeof(lcd_init), 0, lcd_init);
  __bis_SR_register(LPM0_bits + GIE);
  
}


/// Funktion zum Schreiben einer Zeichenkette auf das LCD.
/*!
       ber die Addition eines Offsets wird ein Zeichensatz ausgewhlt der...
       1. Nicht auf dem Kopf steht
       2. Gro- und Kleinbuchstaben erlaubt
       Bisher wird nur die 1. Zeiel des Dispays genutzt


      \param text bergibt eine Zeichenfolge die auf dem Display ausgegeben wird
 */

void LCDwrite(unsigned char* text){
  
  unsigned char i;
  unsigned char length = strlen( (char const*) text);
  unsigned char newtext[12]={0x40};     //! Erstes Byte im String zur Displaysteuerung
  
  for(i = 0; i<length; i++){    //! Jedem Zeichen des Strings einen Offset von +128 hinzufgen damit die Zeichen auf dem LCD nicht auf dem Kopf stehen
    newtext[i+1]=text[i]+128;
  }
  
  
   __disable_interrupt();       //! neugenerierten String an LCD senden
  TI_USI_I2CWrite(LCD_ADDR, sizeof(newtext), 0, (unsigned char*)newtext);
  __bis_SR_register(LPM0_bits + GIE);

 newtext[0]=0x02;  
   __disable_interrupt();       //! Kommando fr "LCD Cursor an Pos. 1
   TI_USI_I2CWrite(LCD_ADDR, 1, 0, (unsigned char*)newtext);
  __bis_SR_register(LPM0_bits + GIE);
  
}  
  
