


#ifndef RTC_ADDR
#define RTC_ADDR 0x68
#endif

#include "msp430g2302.h"
#include "I2C.h"
#include "RTC.h"





/// Stellt die RTC auf ein Datum ein
/*!
       Konfiguration der RTC mit zunchst hardkodierten Werten.
       Damit die Funktion benutzt werden kann, muss UPDATE_RTC definiert werden.

 */
void UpdateRTC()
{
 

  const unsigned char setRTC[] = {
    
    0x00, //Erstes Byte gibt die Pointeradresse an
    
    0x00, //Sekunden
    0x55, //Minuten
    0x22, //Stunden
    
    0x02, //Wochentag (1=Montag, 2=Dienstag...
    0x29, //Tag
    0x11, //Monat
    0x11 //Jahr
      
  };

  
  __disable_interrupt(); //Daten an die RTC senden
  TI_USI_I2CWrite(RTC_ADDR, sizeof(setRTC), 0, (unsigned char*)setRTC);
  __bis_SR_register(LPM0_bits + GIE);
  

}

/// GetTimeDate
/*!
       Funktion zum Auslesen der in der RTC gespeicherten Zeitinformation.
       Asugelesene Werte werden in das bergebene Datenfeld geschrieben.
       

       \param timeDate Fr Call-by-Reference mit Zeiger des timeDate-Datenfeldes

 */

void GetTimeDate(unsigned char* timeDate)
{
  
  unsigned char RxData[7]={0};
  unsigned char rtcpointer[]={0x00};

  
  
  __disable_interrupt(); //Reset RTC Pointer zu 0h
  TI_USI_I2CWrite(RTC_ADDR, sizeof(rtcpointer), 0, (unsigned char*)rtcpointer);
  __bis_SR_register(LPM0_bits + GIE);
  
  /*TI_USI_I2CRead(SlaveAddress,Length,Multi,RxData)*/
  __disable_interrupt();
  TI_USI_I2CRead(RTC_ADDR,7,0,RxData); //! Als letzter Parameter knnte auch timeDate eingesetzt werden.
  __bis_SR_register(LPM0_bits+GIE);

  timeDate[0] = RxData[0];
  timeDate[1] = RxData[1];
  timeDate[2] = RxData[2];
  timeDate[3] = RxData[3];
  timeDate[4] = RxData[4];
  timeDate[5] = RxData[5];
  timeDate[6] = RxData[6];

}



